@@ -1,14 +1,15 @@
 import click
 
+
 @click.group()
 def cli():
     ...
 
+
 @cli.command()
 @click.argument("apikey")
 def apikey(apikey):
-    """Write the API key to the config file, creating if needed
-    """
+    """Write the API key to the config file, creating if needed"""
     from . import _check_apikey
     from . import write_apikey
     from . import CONFIG_FILE
@@ -21,5 +22,6 @@ def apikey(apikey):
     write_apikey(apikey)
     click.echo(f"API Key written to {CONFIG_FILE}")
 
+
 if __name__ == "__main__":
-    cli()
\ No newline at end of file
+    cli()
